"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));
var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));
var childProcess = require('child_process');
var path = require('path');
var fs = require('fs-extra');
var stripAnsi = require('strip-ansi');
var _require = require('@cerner/terra-cli'),
  Logger = _require.Logger;
var logger = new Logger({
  prefix: '[terra-open-source-scripts:version]'
});
var updateChangelogForPackage = require('./updateChangelogForPackage');
var logReleasingPackages = require('./logReleasingPackages');
var VERSION_OUTPUT_PATH = path.join(process.cwd(), 'tmp', 'version-output.txt');
module.exports = /*#__PURE__*/(0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee() {
  var versionOutputContents, packagesAndVersionsRegEx, packagesAndVersionsMatch, packagesAndVersions, updatedPackages, packagePaths;
  return _regenerator.default.wrap(function _callee$(_context) {
    while (1) switch (_context.prev = _context.next) {
      case 0:
        _context.prev = 0;
        _context.next = 3;
        return fs.ensureFile(VERSION_OUTPUT_PATH);
      case 3:
        // Utilize inherit in terms of stdio so that we can interact with the user running the command to capture requested versions.
        // Exec doesn't allow using inherit and when you use inherit the output doesn't get returned. Thus, we use script
        // to capture the output to a file
        childProcess.execSync("script -q ".concat(VERSION_OUTPUT_PATH, " lerna version --no-git-tag-version"), {
          stdio: 'inherit'
        });
        _context.t0 = stripAnsi;
        _context.next = 7;
        return fs.readFile(VERSION_OUTPUT_PATH, 'utf-8');
      case 7:
        _context.t1 = _context.sent;
        versionOutputContents = (0, _context.t0)(_context.t1);
        if (!versionOutputContents.includes('lerna success version finished')) {
          _context.next = 21;
          break;
        }
        // Extract packages and versions from the version output
        packagesAndVersionsRegEx = /- (\S+): \S+ => (\d+.\d+.\d+)/g;
        packagesAndVersionsMatch = packagesAndVersionsRegEx.exec(versionOutputContents);
        packagesAndVersions = [];
        updatedPackages = [];
        while (packagesAndVersionsMatch !== null) {
          updatedPackages.push(packagesAndVersionsMatch[1]);
          packagesAndVersions.push("".concat(packagesAndVersionsMatch[1], "@").concat(packagesAndVersionsMatch[2]));
          packagesAndVersionsMatch = packagesAndVersionsRegEx.exec(versionOutputContents);
        }

        // Update release version in changelog files
        packagePaths = updatedPackages.map(function (x) {
          return "packages/".concat(x.replace('@cerner/', ''));
        });
        _context.next = 18;
        return Promise.all(packagePaths.map(function (packagePath) {
          return updateChangelogForPackage(packagePath);
        }));
      case 18:
        logReleasingPackages(packagesAndVersions);
        _context.next = 22;
        break;
      case 21:
        logger.warn('Lerna version aborted');
      case 22:
        _context.prev = 22;
        fs.remove(VERSION_OUTPUT_PATH);
        return _context.finish(22);
      case 25:
      case "end":
        return _context.stop();
    }
  }, _callee, null, [[0,, 22, 25]]);
}));