"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));
var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));
var spawn = require('@npmcli/promise-spawn');
var _require = require('@cerner/terra-cli'),
  Logger = _require.Logger;
var setupGit = require('./setupGit');
var setupNPM = require('./setupNPM');
var logger = new Logger({
  prefix: '[terra-open-source-scripts:release]'
});

// Manipulate lerna publish output to find what packages were released and need to be tagged.
var getTags = function getTags(output) {
  var successString = 'Successfully published:\n';
  var lastIndexOf = output.lastIndexOf(successString);
  // If we didn't find the success string, we have no tags
  if (lastIndexOf < 0) {
    return null;
  }
  var substring = output.substring(lastIndexOf + successString.length);
  var withoutDashes = substring.replace(/ - /g, '').trim();
  return withoutDashes.split('\n');
};
module.exports = /*#__PURE__*/(0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee() {
  var _yield$spawn, stdout, tags;
  return _regenerator.default.wrap(function _callee$(_context) {
    while (1) switch (_context.prev = _context.next) {
      case 0:
        _context.next = 2;
        return setupNPM();
      case 2:
        _context.next = 4;
        return spawn('npx', ['lerna', 'publish', 'from-package', '--yes'], {
          stdioString: true
        });
      case 4:
        _yield$spawn = _context.sent;
        stdout = _yield$spawn.stdout;
        logger.info(stdout);

        // Retrieve the tags that were published
        tags = getTags(stdout);
        if (!tags) {
          _context.next = 18;
          break;
        }
        _context.next = 11;
        return setupGit();
      case 11:
        logger.info('tags', JSON.stringify(tags, null, 2));

        // Tag based on what was published and push those tags to origin
        _context.next = 14;
        return Promise.all(tags.map(function (tag) {
          return spawn('git', ['tag', '-a', tag, '-m', tag], {
            stdioString: true
          });
        }));
      case 14:
        _context.next = 16;
        return spawn('git', ['push', 'origin', '--tags'], {
          stdioString: true
        });
      case 16:
        _context.next = 19;
        break;
      case 18:
        logger.info('Nothing to tag');
      case 19:
      case "end":
        return _context.stop();
    }
  }, _callee);
}));