"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));
var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));
var path = require('path');
var pacote = require('pacote');
var fs = require('fs-extra');
var spawn = require('@npmcli/promise-spawn');
var _require = require('@cerner/terra-cli'),
  Logger = _require.Logger;
var setupGit = require('./setupGit');
var setupNPM = require('./setupNPM');
var logger = new Logger({
  prefix: '[terra-open-source-scripts:release]'
});

/**
 * Determines whether the name and version of a given package is already published
 * @param {string} name - the name of the package to check
 * @param {string} version - the version of the package to check
 * @returns {boolean} whether or not the package is already published
 */
var isAlreadyPublished = /*#__PURE__*/function () {
  var _ref = (0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee(name, version) {
    var pkgJson, publishedVersions;
    return _regenerator.default.wrap(function _callee$(_context) {
      while (1) switch (_context.prev = _context.next) {
        case 0:
          _context.next = 2;
          return pacote.packument(name, {
            registry: 'https://registry.npmjs.org/'
          });
        case 2:
          pkgJson = _context.sent;
          // Determine if a version is in the list of metadata
          publishedVersions = Object.keys(pkgJson.versions);
          return _context.abrupt("return", publishedVersions.includes(version));
        case 5:
        case "end":
          return _context.stop();
      }
    }, _callee);
  }));
  return function isAlreadyPublished(_x, _x2) {
    return _ref.apply(this, arguments);
  };
}();
module.exports = /*#__PURE__*/(0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee2() {
  var packageFile, _yield$fs$readJSON, name, version, tag;
  return _regenerator.default.wrap(function _callee2$(_context2) {
    while (1) switch (_context2.prev = _context2.next) {
      case 0:
        packageFile = path.resolve(process.cwd(), 'package.json'); // Read package.json and pull out version
        _context2.next = 3;
        return fs.readJSON(packageFile);
      case 3:
        _yield$fs$readJSON = _context2.sent;
        name = _yield$fs$readJSON.name;
        version = _yield$fs$readJSON.version;
        _context2.next = 8;
        return isAlreadyPublished(name, version);
      case 8:
        if (!_context2.sent) {
          _context2.next = 11;
          break;
        }
        logger.info('Nothing to publish');
        return _context2.abrupt("return");
      case 11:
        _context2.next = 13;
        return setupNPM();
      case 13:
        _context2.next = 15;
        return spawn('npm', ['publish'], {
          stdioString: true
        });
      case 15:
        _context2.next = 17;
        return setupGit(name, version);
      case 17:
        // Tag based on what was published and push those tags to origin
        tag = "v".concat(version);
        _context2.next = 20;
        return spawn('git', ['tag', '-a', tag, '-m', tag], {
          stdioString: true
        });
      case 20:
        _context2.next = 22;
        return spawn('git', ['push', 'origin', '--tags'], {
          stdioString: true
        });
      case 22:
      case "end":
        return _context2.stop();
    }
  }, _callee2);
}));